@@ -13,7 +13,28 @@ from tests import TEST_BUCKET_NAME, TEST_PROJECT_NAME
 from tests.base import BaseTestCase
 
 
-class DatasetTestCase(BaseTestCase):
+class TestDataset(BaseTestCase):
+    def _create_nested_cloud_dataset(self, dataset_name="a_dataset"):
+        cloud_storage_client = GoogleCloudStorageClient(TEST_PROJECT_NAME)
+
+        cloud_storage_client.upload_from_string(
+            "[1, 2, 3]", bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_0.txt"
+        )
+
+        cloud_storage_client.upload_from_string(
+            "[4, 5, 6]", bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_1.txt"
+        )
+
+        cloud_storage_client.upload_from_string(
+            "['a', 'b', 'c']", bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/sub-directory/sub_file.txt"
+        )
+
+        cloud_storage_client.upload_from_string(
+            "['blah', 'b', 'c']",
+            bucket_name=TEST_BUCKET_NAME,
+            path_in_bucket=f"{dataset_name}/sub-directory/sub-sub-directory/sub_sub_file.txt",
+        )
+
     def test_instantiates_with_no_args(self):
         """Ensures a Datafile instantiates using only a path and generates a uuid ID"""
         Dataset()
@@ -366,6 +387,41 @@ class DatasetTestCase(BaseTestCase):
             },
         )
 
+    def test_from_cloud_with_nested_dataset_and_no_datafile_json_file(self):
+        """Test that a nested dataset is loaded from the cloud correctly."""
+        self._create_nested_cloud_dataset()
+
+        cloud_dataset = Dataset.from_cloud(
+            project_name=TEST_PROJECT_NAME,
+            cloud_path=f"gs://{TEST_BUCKET_NAME}/a_dataset",
+            recursive=True,
+        )
+
+        self.assertEqual(cloud_dataset.path, f"gs://{TEST_BUCKET_NAME}/a_dataset")
+        self.assertEqual(cloud_dataset.name, "a_dataset")
+        self.assertEqual(
+            {file.name for file in cloud_dataset.files},
+            {"file_0.txt", "file_1.txt", "sub_file.txt", "sub_sub_file.txt"},
+        )
+
+        # Test dataset metadata file has been uploaded.
+        dataset_metadata = json.loads(
+            GoogleCloudStorageClient(TEST_PROJECT_NAME).download_as_string(
+                cloud_path=storage.path.join(cloud_dataset.path, definitions.DATASET_METADATA_FILENAME)
+            )
+        )
+        del dataset_metadata["id"]
+
+        self.assertEqual(
+            set(dataset_metadata["files"]),
+            {
+                "gs://octue-test-bucket/a_dataset/file_0.txt",
+                "gs://octue-test-bucket/a_dataset/file_1.txt",
+                "gs://octue-test-bucket/a_dataset/sub-directory/sub_file.txt",
+                "gs://octue-test-bucket/a_dataset/sub-directory/sub-sub-directory/sub_sub_file.txt",
+            },
+        )
+
     def test_to_cloud(self):
         """Test that a dataset can be uploaded to the cloud via (`bucket_name`, `output_directory`) and via `gs_path`,
         including all its files and a serialised JSON file of the Datafile instance.
@@ -435,17 +491,16 @@ class DatasetTestCase(BaseTestCase):
         """Test that all files in a dataset can be downloaded with one command."""
         storage_client = GoogleCloudStorageClient(project_name=TEST_PROJECT_NAME)
 
-        file_0_path = storage.path.generate_gs_path(TEST_BUCKET_NAME, "file_0.txt")
-        storage_client.upload_from_string(string=json.dumps([1, 2, 3]), cloud_path=file_0_path)
+        dataset_name = "another-dataset"
+        storage_client.upload_from_string(
+            string=json.dumps([1, 2, 3]), bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_0.txt"
+        )
+        storage_client.upload_from_string(
+            string=json.dumps([4, 5, 6]), bucket_name=TEST_BUCKET_NAME, path_in_bucket=f"{dataset_name}/file_1.txt"
+        )
 
-        file_1_path = storage.path.generate_gs_path(TEST_BUCKET_NAME, "file_1.txt")
-        storage_client.upload_from_string(string=json.dumps([4, 5, 6]), cloud_path=file_1_path)
-
-        dataset = Dataset(
-            files={
-                Datafile(path=file_0_path, project_name=TEST_PROJECT_NAME, labels={"hello"}, tags={"a": "b"}),
-                Datafile(path=file_1_path, project_name=TEST_PROJECT_NAME, labels={"goodbye"}, tags={"a": "c"}),
-            },
+        dataset = Dataset.from_cloud(
+            project_name=TEST_PROJECT_NAME, cloud_path=f"gs://{TEST_BUCKET_NAME}/{dataset_name}"
         )
 
         with tempfile.TemporaryDirectory() as temporary_directory:
@@ -456,3 +511,28 @@ class DatasetTestCase(BaseTestCase):
 
             with open(os.path.join(temporary_directory, "file_1.txt")) as f:
                 self.assertEqual(f.read(), "[4, 5, 6]")
+
+    def test_download_all_files_from_nested_dataset(self):
+        """Test that all files in a nested dataset can be downloaded with one command."""
+        self._create_nested_cloud_dataset("nested_dataset")
+
+        dataset = Dataset.from_cloud(
+            project_name=TEST_PROJECT_NAME,
+            cloud_path=f"gs://{TEST_BUCKET_NAME}/nested_dataset",
+            recursive=True,
+        )
+
+        with tempfile.TemporaryDirectory() as temporary_directory:
+            dataset.download_all_files(local_directory=temporary_directory)
+
+            with open(os.path.join(temporary_directory, "file_0.txt")) as f:
+                self.assertEqual(f.read(), "[1, 2, 3]")
+
+            with open(os.path.join(temporary_directory, "file_1.txt")) as f:
+                self.assertEqual(f.read(), "[4, 5, 6]")
+
+            with open(os.path.join(temporary_directory, "sub-directory", "sub_file.txt")) as f:
+                self.assertEqual(f.read(), "['a', 'b', 'c']")
+
+            with open(os.path.join(temporary_directory, "sub-directory", "sub-sub-directory", "sub_sub_file.txt")) as f:
+                self.assertEqual(f.read(), "['blah', 'b', 'c']")
